@@ -120,6 +120,9 @@ defaults = [
     ('write_buffer_size', 4,
         'the maximum amount of space to use for buffering disk writes ' +
         '(in megabytes, 0 = disabled)'),
+    ('breakup_seed_bitfield', 1,
+        'sends an incomplete bitfield and then fills with have messages, '
+        'in order to get around stupid ISP manipulation'),
     ('snub_time', 30.0,
         "seconds to wait for data to come in over a connection before assuming it's semi-permanently choked"),
     ('spew', 0,
@@ -545,8 +548,7 @@ class BT1Download:
     def _make_upload(self, connection, ratelimiter, totalup):
         return Upload(connection, ratelimiter, totalup,
                       self.choker, self.storagewrapper, self.picker,
-                      self.config['max_slice_length'], self.config['max_rate_period'],
-                      self.config['upload_rate_fudge'], self.config['buffer_reads'])
+                      self.config)
 
     def _kick_peer(self, connection):
         def k(connection = connection):
@@ -673,7 +675,7 @@ class BT1Download:
                     self.connecter, self.httpdownloader, self.ratelimiter,
                     self.rerequest_lastfailed, self.filedatflag)
         if self.info.has_key('files'):
-            self.statistics.set_dirstats(self.files, self.len_pieces, self.info['piece length'])
+            self.statistics.set_dirstats(self.files, self.info['piece length'])
         if self.config['spew']:
             self.spewflag.set()
 
